use v5.14;
package App::ansifold;
our $VERSION = "1.11";

use warnings;

use Exporter 'import';
our @EXPORT_OK = qw($VERSION);

1;
__END__

=head1 NAME

App::ansifold - fold command handling ANSI terminal sequences

=head1 LICENSE

Copyright (C) Kazumasa Utashiro.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=head1 AUTHOR

Kazumasa Utashiro

=cut
